@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -50,7 +50,7 @@ ManageThemes::ManageThemes(const QString &relativeThemePath, QWidget *parent)
     , d(new GrantleeThemeEditor::ManageThemesPrivate)
 {
     d->mLocalDirectory = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + relativeThemePath;
-    setWindowTitle(i18n("Manage Theme"));
+    setWindowTitle(i18nc("@title:window", "Manage Theme"));
     QWidget *w = new QWidget;
 
     QVBoxLayout *lay = new QVBoxLayout(w);
